package cn.iocoder.yudao.module.jx.mapper;

import cn.iocoder.yudao.module.jx.domain.DriveSchoolUpkeep;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 车辆保养记录Mapper接口
 *
 * @author ruoyi
 * @date 2024-04-01
 */
@Mapper
public interface DriveSchoolUpkeepMapper
{
    /**
     * 查询车辆保养记录
     *
     * @param id 车辆保养记录主键
     * @return 车辆保养记录
     */
    public DriveSchoolUpkeep selectDriveSchoolUpkeepById(Long id);

    /**
     * 查询车辆保养记录列表
     *
     * @param driveSchoolUpkeep 车辆保养记录
     * @return 车辆保养记录集合
     */
    public IPage<DriveSchoolUpkeep> selectDriveSchoolUpkeepList(@Param("entity") DriveSchoolUpkeep driveSchoolUpkeep, Page<DriveSchoolUpkeep> page);

    /**
     * 新增车辆保养记录
     *
     * @param driveSchoolUpkeep 车辆保养记录
     * @return 结果
     */
    public int insertDriveSchoolUpkeep(DriveSchoolUpkeep driveSchoolUpkeep);

    /**
     * 修改车辆保养记录
     *
     * @param driveSchoolUpkeep 车辆保养记录
     * @return 结果
     */
    public int updateDriveSchoolUpkeep(DriveSchoolUpkeep driveSchoolUpkeep);

    /**
     * 删除车辆保养记录
     *
     * @param id 车辆保养记录主键
     * @return 结果
     */
    public int deleteDriveSchoolUpkeepById(Long id);

    /**
     * 批量删除车辆保养记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDriveSchoolUpkeepByIds(Long[] ids);
}
